==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/lib/plugins/usermanager/lang/de/lang.php <==
<?php
/**
 * German language file
 *
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Andreas Gohr <andi@splitbrain.org>
 */
 
$lang['menu'] = 'Benutzerverwaltung'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(Authentifizierungssystem nicht verfügbar)';
$lang['nosupport']   = '(Benutzerverwaltung nicht unterstützt)';

$lang['badauth']     = 'Ungültige Methode zur Authentifizierung';

$lang['user_id']     = 'Benutzer';
$lang['user_pass']   = 'Passwort';
$lang['user_name']   = 'Name';
$lang['user_mail']   = 'Email';
$lang['user_groups'] = 'Gruppen';

$lang['field']       = 'Feld';
$lang['value']       = 'Wert';
$lang['add']         = 'Hinzufügen';
$lang['delete']      = 'Löschen';
$lang['delete_selected'] = 'Ausgewählte löschen';
$lang['edit']        = 'Ändern';
$lang['edit_prompt'] = 'Benutzerdaten ändern';
$lang['modify']      = 'Speichern';
$lang['search']      = 'Suchen';
$lang['search_prompt'] = 'Benutzerdaten filtern';
$lang['clear']       = 'Filter zurücksetzen';
$lang['filter']      = 'Filter';

$lang['summary']     = 'Zeige Benutzer %1$d-%2$d von %3$d gefundenen. %4$d Benutzer insgesamt.';
$lang['nonefound']   = 'Keine Benutzer gefunden. %d Benutzer insgesamt.';
$lang['delete_ok']   = '%d Benutzer gelöscht';
$lang['delete_fail'] = '%d konnten nicht gelöscht werden.';
$lang['update_ok']   = 'Benutzerdaten erfolgreich geändert.';
$lang['update_fail'] = 'Änderung der Benutzerdaten fehlgeschlagen.';
$lang['update_exists'] = 'Nutzername konnte nicht geändert werden, weil der angegebene Nutzer (%s) bereits existiert (alle anderen Änderungen wurden durchgeführt).';


$lang['start']  = 'Anfang';
$lang['prev']   = 'Vorherige';
$lang['next']   = 'Nächste';
$lang['last']   = 'Ende';

?>

==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/lib/plugins/usermanager/lang/de/lang.php <==
<?php
/**
 * German language file
 *
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Andreas Gohr <andi@splitbrain.org>
 */
 
$lang['menu'] = 'Benutzerverwaltung'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(Authentifizierungssystem nicht verfügbar)';
$lang['nosupport']   = '(Benutzerverwaltung nicht unterstützt)';

$lang['badauth']     = 'Ungültige Methode zur Authentifizierung';

$lang['user_id']     = 'Benutzer';
$lang['user_pass']   = 'Passwort';
$lang['user_name']   = 'Name';
$lang['user_mail']   = 'Email';
$lang['user_groups'] = 'Gruppen';

$lang['field']       = 'Feld';
$lang['value']       = 'Wert';
$lang['add']         = 'Hinzufügen';
$lang['delete']      = 'Löschen';
$lang['delete_selected'] = 'Ausgewählte löschen';
$lang['edit']        = 'Ändern';
$lang['edit_prompt'] = 'Benutzerdaten ändern';
$lang['modify']      = 'Speichern';
$lang['search']      = 'Suchen';
$lang['search_prompt'] = 'Benutzerdaten filtern';
$lang['clear']       = 'Filter zurücksetzen';
$lang['filter']      = 'Filter';

$lang['summary']     = 'Zeige Benutzer %1$d-%2$d von %3$d gefundenen. %4$d Benutzer insgesamt.';
$lang['nonefound']   = 'Keine Benutzer gefunden. %d Benutzer insgesamt.';
$lang['delete_ok']   = '%d Benutzer gelöscht';
$lang['delete_fail'] = '%d konnten nicht gelöscht werden.';
$lang['update_ok']   = 'Benutzerdaten erfolgreich geändert.';
$lang['update_fail'] = 'Änderung der Benutzerdaten fehlgeschlagen.';
$lang['update_exists'] = 'Nutzername konnte nicht geändert werden, weil der angegebene Nutzer (%s) bereits existiert (alle anderen Änderungen wurden durchgeführt).';


$lang['start']  = 'Anfang';
$lang['prev']   = 'Vorherige';
$lang['next']   = 'Nächste';
$lang['last']   = 'Ende';

$lang['edit_usermissing'] = 'Der usgewählte Nutzer wurde nicht gefunden. Möglicherweise wurde er gelöscht oder der Nutzer wurde anderswo geändert.';
$lang['user_notify'] = 'Nutzer benachrichtigen';
$lang['note_notify'] = 'Benachrichtigungsmails werden nur versandt wenn ein neues Passwort vergeben wurde.';
$lang['note_group']  = 'Neue Nutzer werden der Standard-Gruppe (%s) hinzugefügt, wenn keine Gruppe angegeben wurde.';
$lang['add_ok']      = 'Nutzer erfolgreich angelegt';
$lang['add_fail']    = 'Nutzer konnte nicht angelegt werden';
$lang['notify_ok']   = 'Benachrichtigungsmail wurde versandt';
$lang['notify_fail'] = 'Benachrichtigungsmail konnte nicht versandt werden';
